@@ -18,6 +18,7 @@ and creating SQL views for reporting.
 
 import typing
 from asyncio import Semaphore
+from collections import OrderedDict
 from decimal import Decimal, InvalidOperation
 from functools import lru_cache
 from logging import getLogger
@@ -75,6 +76,9 @@ from dao_treasury.constants import CHAINID
 from dao_treasury.types import TxGroupDbid, TxGroupName
 
 
+EventItem = _EventItem[_EventItem[OrderedDict[str, Any]]]
+
+
 SQLITE_DIR = Path(path.expanduser("~")) / ".dao-treasury"
 """Path to the directory in the user's home where the DAO treasury SQLite database is stored."""
 
@@ -250,6 +254,10 @@ class Address(DbEntity):
     def contract(self) -> Contract:
         return Contract(self.address)
 
+    @property
+    def contract_coro(self) -> Coroutine[Any, Any, Contract]:
+        return Contract.coroutine(self.address)
+
     @staticmethod
     @lru_cache(maxsize=None)
     def get_dbid(address: HexAddress) -> int:
@@ -420,6 +428,10 @@ class Token(DbEntity):
     def contract(self) -> Contract:
         return Contract(self.address.address)
 
+    @property
+    def contract_coro(self) -> Coroutine[Any, Any, Contract]:
+        return Contract.coroutine(self.address.address)
+
     @property
     def scale(self) -> int:
         """Base for division according to `decimals`, e.g., `10**decimals`.
@@ -755,10 +767,10 @@ class TreasuryTx(DbEntity):
     @overload
     def get_events(
         self, event_name: str, sync: Literal[False]
-    ) -> Coroutine[Any, Any, _EventItem]: ...
+    ) -> Coroutine[Any, Any, EventItem]: ...
     @overload
-    def get_events(self, event_name: str, sync: bool = True) -> _EventItem: ...
-    def get_events(self, event_name: str, sync: bool = True) -> _EventItem:
+    def get_events(self, event_name: str, sync: bool = True) -> EventItem: ...
+    def get_events(self, event_name: str, sync: bool = True) -> EventItem:
         if not sync:
             return _EVENTS_THREADS.run(self.get_events, event_name)
         try:
